==> qtify_0.0.2.tar.gz: qtify-0.0.2/translations/qtify_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="fi">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Playlist</source>
        <translation type="unfinished">Soittolista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <source>Artist</source>
        <translation type="unfinished">Artisti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Album</source>
        <translation type="unfinished">Albumi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>Rating</source>
        <translation type="unfinished">Lukema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>Search</source>
        <translation type="unfinished">Etsi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="446"/>
        <source>Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="144"/>
        <source>Username</source>
        <translation type="unfinished">Käyttäjänimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Password</source>
        <translation type="unfinished">Salasana</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="181"/>
        <source>Login</source>
        <translation type="unfinished">Kirjaudu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Show</source>
        <translation type="obsolete">Näytä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="298"/>
        <source>Title</source>
        <translation type="unfinished">Kappaleen nimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Duration</source>
        <translation type="unfinished">Kesto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Play/Pause</source>
        <translation type="obsolete">Play/Pause</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>Incorrect credentials entered
please try again.</source>
        <translation type="unfinished">Väärä käyttäjänimi tai salasana, yritä uudelleen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="70"/>
        <source>Authenticating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Updating playlists...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="112"/>
        <source>Select playlist</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qtify_0.0.3.tar.gz: qtify-0.0.3/translations/qtify_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="515"/>
        <source>Playlist</source>
        <translation type="unfinished">Soittolista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>Artist</source>
        <translation type="unfinished">Artisti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>Album</source>
        <translation type="unfinished">Albumi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Rating</source>
        <translation type="unfinished">Lukema</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <location filename="../mainwindow.ui" line="520"/>
        <source>Search</source>
        <translation type="unfinished">Etsi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Recent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>Username</source>
        <translation type="unfinished">Käyttäjänimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Password</source>
        <translation type="unfinished">Salasana</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>Login</source>
        <translation type="unfinished">Kirjaudu</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="obsolete">Näytä</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Title</source>
        <translation type="unfinished">Kappaleen nimi</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="380"/>
        <source>Duration</source>
        <translation type="unfinished">Kesto</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation type="obsolete">Play/Pause</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>Incorrect credentials entered
please try again.</source>
        <translation>Väärä käyttäjänimi tai salasana, yritä uudelleen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="70"/>
        <source>Authenticating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="81"/>
        <source>Updating playlists...</source>
        <translation>Päivittää soittolistoja</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <location filename="../mainwindow.cpp" line="113"/>
        <source>Select playlist</source>
        <translation>Valitse soittolista</translation>
    </message>
</context>
</TS>
